==> estateplat-common-1.1.0-20170216.021426-266-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwXmxx.java <==
package cn.gtmap.estateplat.model.server.core;

import org.springframework.data.annotation.Id;

import javax.persistence.Table;

/**
 * Created by Administrator on 2015/5/7.
 */
@Table(name = "djsj_fw_xmxx")
public class DjsjFwXmxx {
    @Id
    private String fwXmxxIndex;
    private String lszd;
    private double dytdmj;
    private double fttdmj;
    private double jyjg;
    private String cqly;
    private String bdcdyh;
    private String gyqk;
    private String bz;
    private String zl;
    private String fwlx;
    private String fwxz;
    private String xmmc;

    public String getFwXmxxIndex() {
        return fwXmxxIndex;
    }

    public void setFwXmxxIndex(String fwXmxxIndex) {
        this.fwXmxxIndex = fwXmxxIndex;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public double getJyjg() {
        return jyjg;
    }

    public void setJyjg(double jyjg) {
        this.jyjg = jyjg;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }
}

==> estateplat-common-1.2.3-20180109.015111-8-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwXmxx.java <==
package cn.gtmap.estateplat.model.server.core;

import org.springframework.data.annotation.Id;

import javax.persistence.Table;

/**
 * Created by Administrator on 2015/5/7.
 */
@Table(name = "djsj_fw_xmxx")
public class DjsjFwXmxx {
    @Id
    private String fwXmxxIndex;
    private String lszd;
    private double dytdmj;
    private double fttdmj;
    private double jyjg;
    private String cqly;
    private String bdcdyh;
    private String gyqk;
    private String bz;
    private String zl;
    private String fwlx;
    private String fwxz;
    private String xmmc;
    private String bdczt;//不动产状态

    public String getFwXmxxIndex() {
        return fwXmxxIndex;
    }

    public void setFwXmxxIndex(String fwXmxxIndex) {
        this.fwXmxxIndex = fwXmxxIndex;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public double getJyjg() {
        return jyjg;
    }

    public void setJyjg(double jyjg) {
        this.jyjg = jyjg;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getBdczt() {
        return bdczt;
    }

    public void setBdczt(String bdczt) {
        this.bdczt = bdczt;
    }
}
